package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"(```````!``````````""Q````
M`````````$``.``+`$``&@`9``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````'`:````````<!H`````````
M$`````````$````%`````"``````````(``````````@````````C3L`````
M``"-.P`````````0`````````0````0`````8`````````!@`````````&``
M``````#H10```````.A%`````````!`````````!````!@```,"K````````
MP+L```````#`NP```````&`$````````X!0`````````$`````````(````&
M````T*L```````#0NP```````-"[````````(`(````````@`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````)">````````D)X```````"0G@``
M`````/P`````````_``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#`JP```````,"[````````P+L```````!`!````````$`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`!')RH7F[NO)^I(AMKE97.+]!+I.!````!`````!````1TY5```````#
M`````@`````````]````0`````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(01;H``@H``````````$``````````00```$,```!%````````
M`$8`````````1P```$@```!)````2P``````````````3```````````````
M``````````````````````````!-````3@```%````!2````````````````
M````4P````````!4`````````%4``````````````%8```!7`````````%@`
M``!9````````````````````6@````````!;``````````````!<````70``
M`%\``````````````&``````````````````````````N^.2?*;=HVMK&IY0
M+L6;MD/ZUX<5C"7,9Z_,9F_%WQ^)!W#3Q(D%D*/@^TG[H6Q@U634?,/E/RQ^
MJ9R;K4OCP.)'Q@'/WD<M#13BGB'_Y`[AIP(*V\WCG@N*$%>S`8MO#3J7"]EQ
M6!Q7I)N6,V+;[6L)0];$N9Q`.?*+'$-%U>QK?YI\````````````````````
M````````````&@$``!(`````````````````````````B@$``!(`````````
M````````````````Y`$``!(`````````````````````````P@$``!(`````
M`````````````````````0```"``````````````````````````ZP$``!(`
M````````````````````````=P(``!(```````````````````````````(`
M`!(`````````````````````````EP```!(`````````````````````````
M7P(``!(`````````````````````````5P(``!(`````````````````````
M````V````!(`````````````````````````2@,``!(`````````````````
M````````%0$``!(`````````````````````````(P(``!(`````````````
M````````````%0(``!(`````````````````````````TP$``!(`````````
M````````````````<`(``!(`````````````````````````@`(``!(`````
M````````````````````YP```!(`````````````````````````NP```!(`
M````````````````````````]0```!(`````````````````````````MP$`
M`!(`````````````````````````R@$``!(`````````````````````````
MX`(``!(`````````````````````````'P$``!(`````````````````````
M````^0$``!(`````````````````````````A0$``!(`````````````````
M````````Q`(``!(`````````````````````````O0(``!(`````````````
M````````````4P```!(`````````````````````````'0```"``````````
M````````````````-P(``!(`````````````````````````,@$``!(`````
M````````````````````HP$``!(`````````````````````````*P$``!(`
M````````````````````````@````!(```````````````````````````$`
M`!(`````````````````````````C````!(`````````````````````````
M4@$``!(`````````````````````````90$``!(`````````````````````
M````8P```!(`````````````````````````/@(``!(`````````````````
M````````L````!(`````````````````````````00$``!(`````````````
M````````````\0$``!(`````````````````````````?@$``!(`````````
M````````````````K@(``!(`````````````````````````AP(``!(`````
M````````````````````;P```!(`````````````````````````M@(``!(`
M````````````````````````#@(``!(`````````````````````````R0``
M`!(`````````````````````````IP```!(`````````````````````````
M3`(``!(`````````````````````````O0$``!(`````````````````````
M````FP$``!(`````````````````````````*0(``!(`````````````````
M````````+````"``````````````````````````!P(``!(`````````````
M````````````D0(``"(`````````````````````````'`(``!(`````````
M````````````````H`(``!(`````````````````````````XP,``!``%P"@
MT```````````````````V`(``"$`%P!`P`````````@`````````]0,``!(`
M#0#P6````````/L!````````)P,``!(`#0#@*P````````4`````````C`,`
M`!(`#0!`5P```````*<!````````0`0``!(`#0#@5@```````%4`````````
M<P,``!(`#0`P+@```````!T`````````4P,``!(`#0"`/P```````#\!````
M````V0,``!$`%@`8P`````````@`````````UP(``"$`%P!`P`````````@`
M````````Z`,``!(`#0!0+@```````*<$````````(`0``!(`#0"@,P``````
M`!`!````````200``!(`#0#`/````````+$"````````"P0``!(`#0#0*@``
M`````#(`````````.`,``!(`#0"`,P```````!\`````````I`,``!$`#P``
M8`````````0`````````9@,``!(`#0``+@```````"4`````````?P,``!(`
M#0"P-`````````$(````````%P,``!(`#0!@6P````````4`````````$P0`
M`!(`#0#P*P````````4"````````LP,``!(`#0`0*P```````,4`````````
MR0,``!(`#0#P6@```````&4`````````1@```!$`%P`PP`````````$`````
M````,@0``!(`#0``,P```````'4`````````F0,``"``%@``P```````````
M````````_P,``!``%P`@P```````````````````<P$``!$`%P`@P```````
M``0`````````G0,``!(`#0!@(@```````"\`````````EP,``!``%@``P```
M````````````````U@(``!$`%P!`P`````````@`````````:0(``!$`%P!@
MP`````````@`````````7P,``!``%@`@P```````````````````T0(``!(`
M#0!`(````````!X"`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,
M7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H<'8`4&5R;%]M9U]S970`4&5R;%]A
M=&9O<FM?;&]C:P!097)L7V=E=%]S=@!097)L7VYE=UA3`&)O;W1?1'EN84QO
M861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E<FQ?<W9?<V5T<'8`4&5R;%]S
M=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R;%]D97-T<G5C=`!P97)L7V%L
M;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E90!097)L7W-A9F5S
M>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G<P!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T:')?:V5Y`&]P96XV
M-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T
M870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`
M7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`&QI8G!E<FPN<V\`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!?
M7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?
M9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`'!A<E]I;FET7V5N=@!S:&%?
M9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA
M;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ
M-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`+W5S<B]L:6(O<&5R;#4O-2XS,B]C
M;W)E7W!E<FPO0T]210`````"``,``@`"`````@`"``(````"``(````"````
M`@`"``0``@`"``````````,``@`%`````@`#``(``@``````!@````,``@``
M```````````````'```````"``,``@`"`````@`"```````"``(``P`'````
M`@`"``(`!P`!``(``0`!``$``0`!``$``0`"``$``0`!``$``0`!``$``0`!
M``$``0`!`````0`!``$````!``$``@`"``$``0````$``0#]`@``$````"``
M``!U&FD)```#`%\$`````````0`%``T#```0`````````'09:0D```<`:P0`
M`!````"4D98&```&`'<$```0````<AEI"0``!0""!```$````!1I:0T```0`
MC@0``!````!U&FD)```"`%\$````````P+L````````(`````````%`C````
M````R+L````````(```````````C````````",`````````(``````````C`
M````````&,`````````(`````````.!B````````$+X````````&`````0``
M````````````&+X````````&`````@``````````````(+X````````&````
M`P``````````````*+X````````&````!```````````````,+X````````&
M````!0``````````````.+X````````&````!@``````````````0+X`````
M```&````!P``````````````2+X````````&````"```````````````4+X`
M```````&````"0``````````````6+X````````&````"@``````````````
M8+X````````&````"P``````````````:+X````````&````#```````````
M````<+X````````&````#0``````````````>+X````````&````#@``````
M````````@+X````````&````#P``````````````B+X````````&````$```
M````````````D+X````````&````$0``````````````F+X````````&````
M$@``````````````H+X````````&````$P``````````````J+X````````&
M````%```````````````L+X````````&````%0``````````````N+X`````
M```&````%@``````````````P+X````````&````%P``````````````R+X`
M```````&````&```````````````T+X````````&````&@``````````````
MV+X````````&````&P``````````````X+X````````&````'```````````
M````Z+X````````&````'0``````````````\+X````````&````'@``````
M````````^+X````````&````'P```````````````+\````````&````(```
M````````````"+\````````&````(0``````````````$+\````````&````
M(@``````````````&+\````````&````(P``````````````(+\````````&
M````)```````````````*+\````````&````)0``````````````,+\`````
M```&````)@``````````````.+\````````&````)P``````````````0+\`
M```````&````*```````````````2+\````````&````*0``````````````
M4+\````````&````*@``````````````6+\````````&````*P``````````
M````8+\````````&````+```````````````:+\````````&````+0``````
M````````<+\````````&````+@``````````````>+\````````&````+P``
M````````````@+\````````&````,```````````````B+\````````&````
M,0``````````````D+\````````&````,@``````````````F+\````````&
M````,P``````````````H+\````````&````-```````````````J+\`````
M```&````-0``````````````L+\````````&````-@``````````````N+\`
M```````&````-P``````````````P+\````````&````.```````````````
MR+\````````&````.0``````````````T+\````````&````.@``````````
M````V+\````````&````.P``````````````X+\````````&````/```````
M````````Z+\````````&````/0``````````````\+\````````&````/@``
M````````````^+\````````&````/P``````````````(,`````````%````
M6@``````````````,,`````````%````5@``````````````0,`````````%
M````70``````````````8,`````````%````7@``````````````"+X`````
M```'````&0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!?&>``!(A<!T`O_02(/$",,``````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@____05152(/L.(E\)!Q(C7PD'$B)="002(UT
M)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP/\5EIX``$B+-;^>``!(BST(
MGP``2(GR9^C?.@``@#V8GP```'4R_Q48G@``2(D%\:\``$B)QTB%P`^$F@$`
M`/\5KYT``(L]89\``/\54YX``,:`Z0D```"+/4Z?``#_%4">``"+/4*?``"`
MB#H$```"_Q4MG@``@(@Z!````8M$)!R->`1$C6`#2&/_2,'G`_\5QIT``$B+
M3"00BW0D'$F)P4B)!7.O``!(BP%)B0%(C06D0```28E!"$B+!>.>``!)B4$0
M2(T%D4```$F)01B#_@$/CO8```!(@\$(@\8#N`0````/'X``````2(LY2&/0
M@\`!2(/!"$F)/-$YQG7K2&/V2,'F`T2)XDB+/1*O``!%,<!,B<E)QP0Q````
M`$B--<4(``#_%;^=``!!B<2%P'162(UL)"1(BSWDK@``_Q7NG```,<!(B>Y(
MC3W=/@``Z)4!``!(A<!T0$B+/<&N``#_%9N<``#_%66=``!(BT0D*&1(*P0E
M*````'5E2(/$.$2)X%U!7,-(BSV3K@``_Q6EG0``08G$ZYA(BSUQK@``2(7_
M=`?H7QT``.NM2(T],#X``$B)[N@N`0``2(D%3ZX``$B)QTB%P'2/Z]F^(```
M`.DO____OP$```#_%6B=``#_%3*<``!FD/,/'OHQ[4F)T5Y(B>)(@^3P4%1,
MC07F.```2(T-;S@``$B-/;C]____%5J<``#TD$B-/8F=``!(C06"G0``2#GX
M=!5(BP6&FP``2(7`=`G_X`\?@`````###Q^``````$B-/5F=``!(C352G0``
M2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!>V<``!(A<!T"/_@9@\?1```PP\?
M@`````#S#Q[Z@#U=G0```'4S54B#/=*<````2(GE=`U(BSWFG```_Q7`G```
MZ&/____&!32=```!7<-F+@\?A```````PV9F+@\?A```````#Q]``/,/'OKI
M9____P\?@`````!!5T%6055!5%532(/L"$B%_P^$L0```$R++<*<``!-A>T/
MA*$````/M@=)B?](B?6$P'0$/#UU6$4Q]DV+90!-A>1T,TUC]DR)ZV8/'T0`
M`$R)\DR)_DR)Y_\5:9H``(7`=0=#@#PT/71&3(MC"$B#PPA-A>1UV4B#Q`A,
MB>!;74%<05U!7D%?PP\?@`````!)B?Y!#[9&`4F#Q@&$P'0$/#UU[T4I_NN2
M#Q^``````$PIZT^-9#0!2,'[`XE=`.NV#Q^``````$4QY.NJ#Q\`059!54%4
M55-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]=3%(BX0D
MF````&1(*P0E*`````^%00$``$B!Q*````!;74%<05U!7L-F+@\?A```````
M_Q7*F0``28G$2(7`=,%)B>5,B>?_%=Z:``!(A<`/A+T```"`>!,N2(U8$W4+
M@'L!`'3>#Q]$``"`>!,N#X2^````2(GO_Q6MF0``2(G?28G&_Q6AF0``08U\
M!@)(8___%2N:``!)B=E)B>B^`0```$F)QDB)QS'`2,?"_____TB-#>XZ``#_
M%=R:``"_`0```$R)ZDR)]O\5*YD``$R)]X/X_W00BT0D&"4`\```/0!```!T
M:_\5U9@``$R)]_\5O)@``$R)Y_\5*YH``$B%P`^%3?___V8N#Q^$``````!,
MB>?_%4^9``!(B>__%?Z8``#IV/[__V8/'X0``````(![`2X/A3C___^`>P(`
M#X3]_O__Z2G___\/'X``````Z'O^___KE/\5TY@```\?`%5(B?Y(B?V_`0``
M`$B![*````!D2(L$)2@```!(B80DF````#'`2(GB_Q7)F0``A<!U-8M4)!B!
MX@#P``"!^@!```!T"('Z`*```'4=O@(```!(B>__%7V9``"%P`^4P`^VP.L%
M#Q\`,<!(BXPDF````&1(*PPE*````'4)2('$H````%W#_Q5$F```#Q]``%5(
MB?W_%2Z8``!(C50%_T@YU7(5Z9$````/'X``````2(/J`4@YU70E@#HO=/)(
M.=5S=TB#Z@%(.=5T$@\?0`"`.B]T*$B#Z@%(.=5U\H!]`"]T9$B-/6$Y``!=
M_R4NF0``9@\?1```@#HO=0E(@^H!2#G5<O)(*>HQP$B-2@)(@?D`$```=R!(
M@\(!N0`0``!(B>Y(C3V5F0``_Q5GF```2(T%B)D``%W#2#G5=;[KG0\?@```
M``!(C3W[.```7?\ERI@``&8N#Q^$``````!!5[K_#P``059!54%428GT54B)
M_4B-/=,X``!(@>P0$```9$B+!"4H````2(F$)`@0```QP$F)Y4R)[O\5WY8`
M`(7`?GN-4/]$BSVQF```3&/R0H`\-`!U7X72=&I,B?*^+P```$R)[_\52I<`
M`$B%P'141(G__Q5\EP``3(GQ3(GJ2(GN2(G'_Q7ZEP``2(N$)`@0``!D2"L$
M)2@```!U0$B!Q!`0``!=05Q!74%>05_#9@\?1```3&/PZZ`/'P!$BSTYF```
M1(G__Q4HEP``3(GB2(GN2(G'_Q6QE@``ZZW_%8F6``!F#Q^$``````!!5T%6
M055!5%5(B?532(G[2(/L&&1(BP0E*````$B)1"0(,<`QP(`^/0^4P$@!Q4B)
M[_\50)8``$B-="0$2(G?28G$,<#H!OO__TB%P`^$#0$``$F)Q4B)Q_\5&98`
M`$DYQ`^&V````$QC="0$2<'F`P^V`X3`#X2L`0``/#T/A*0!``!(B=AF#Q^$
M```````/ME`!2(/``832=`6`^CUU[T@IV$B83`,U@Y<``$J-?"`"_Q58E@``
M28D&2(7`=%E(BP5IEP``2&-4)`1(C4L!2(L4T`^V`X@"A,!T(#P]=0OK&@\?
M1```A,!T$0^V`4B#P@%(@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(
M@\`!A,EU[TB+1"0(9$@K!"4H````#X4/`0``2(/$&%M=05Q!74%>05_##Q]`
M`#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``3(L]R98``$F#/P`/
MA+X```!,B?A%,>UF#Q^$``````!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!
MY@.+!<^F``"%P'5;QP7!I@```0```$B)]_\56)4``$B%P`^$6/___TUC]4R)
M_DB)QTG!Y@-,B?+_%9F5``!(B052E@``2(G!08U%`4B82,<$P0````!$B6PD
M!.EX_O__#Q^``````$R)__\55Y4``$B)!2"6``!(B<%(A<`/A/W^__]-8_5)
MP>8#Z[P/'P`QP.EW_O__OA````!%,>WI7_____\5/I0``&9F+@\?A```````
M#Q\`2(/L"(L]MI4``/\5J)0``(L]JI4``/\5G)0``$B+%<V3``!(C0W6<P``
M2(TUC#4``$B)Q_\5GI0``(L]@)4``/\5<I0``$R-!?XV``!%,<E(C14)$@``
M2(G'3(G!2(TU=34``$B#Q`C_)9J4``!FD$B#[`B+/4:5``#_%3B4``!(BQ5I
MDP``2(/$"$B-#6YS``!(B<=(C34A-0``_R4VE```9F8N#Q^$```````/'P!!
M5%532('L("```&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```/\5"9,`
M`$R-#=,T``"Z`1```$B)[T&)P$B-#?8T``"^`0```#'`_Q63E```N@`0``!,
MB>9(B>__%<J2``!%,<"%P'@PC7@!2(G#2&/__Q64DP``28G`2(7`=!E(8]M,
MB>9(B<=(B=K_%6*3``#&!!@`28G`2(N$)!@@``!D2"L$)2@```!U#TB!Q"`@
M``!,B<!;74%<P_\5NY(``&9F+@\?A```````Z2O___]F9BX/'X0``````$%7
M059!54F)]4%454B)_4B-/50T``!32('LN!```&1(BP0E*````$B)A"2H$```
M,<!(C70D#.@U]___OB\```!(B>](B</_%622``!(A<!T/S'`2(GN2(T]%C0`
M`.B^^___2(GH2(N<)*@0``!D2"L<)2@````/A8,!``!(@<2X$```6UU!7$%=
M05Y!7\-FD$B)[_\5_Y$``$B-->`S``!,B>]!B<3_%023``!)B<9(A<!TG4&`
M/@!,C2U;,P``#X3?````#Q\`2(7;=!1,B?9(B=__%2>2``"%P`^$G@```$R)
M]_\5KI$``(U0_XG!2&/"3`'P@#@O=1EF#Q]$``")T8/J`<8``$ACPDP!\(`X
M+W3M0HU$(0$]_P\```^/+O___TV)\+H`$```O@$````QP$R-O"2@````2(/L
M"$B-#3$T``!53(T-SS(``$R)__\5LI(``$R)_K\!````2(U4)"#_%?^0``!:
M687`=1"+1"0H)0#P```]`(```'112(TU^C(``#'__Q4BD@``28G&2(7`#X2W
M_O__08`^``^%)/___TB%VW0%@#LN=!)-B>ZY`0```.E8____#Q]$``"`>P$`
M=+GKY@\?A```````O@$```!,B?__%<J1``"%P'6=3(G^2(T]AS(``.@O^O__
M3(G__Q7VD0``Z6;^____%9N0``!F9BX/'X0```````^V!TF)^(3`=!=F#Q]$
M``!(@\<!/"\/M@=,#T3'A,!U[TR)P,-F9BX/'X0``````$B%_W0+@#\`=`;I
M$?C__Y!(C3W#,0``_R63D0``#Q\`55-(C1T9,@``2(/L2&8/;P4+<```9$B+
M!"4H````2(E$)#@QP#'`2(UL)`P/$40D$&8/;P7W;P``9HE$)#`/$40D(`\?
M1```,<!(B>Y(B=_HN_3__TB%P'0^2&-4)`Q(BP6*D0``2(T$T$B+4`A(B1!(
MA=)TTF8N#Q^$``````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1V,,0``
MD#'`2(GN2(G?Z&/T__](A<!T-DAC5"0,2(L%,I$``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'40Q``"0,<!(B>Y(B=_H
M$_3__TB%P'0V2&-4)`Q(BP7BD```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#
MP`A(B1!(A=)U\.N^9@\?1```2(T=_3```)`QP$B)[DB)W^C#\___2(7`=#9(
M8U0D#$B+!9*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7P
MZ[YF#Q]$``!(C1VT,```D#'`2(GN2(G?Z'/S__](A<!T-DAC5"0,2(L%0I``
M`$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-
M'70P``"0,<!(B>Y(B=_H(_/__TB%P'0V2&-4)`Q(BP7RCP``2(T$T$B+4`A(
MB1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=VR\``)`QP$B)
M[DB)W^C3\O__2(7`=#9(8U0D#$B+!:*/``!(C0302(M0"$B)$$B%TG329I!(
MBU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1W@+P``D#'`2(GN2(G?Z(/R__](
MA<!T-DAC5"0,2(L%4H\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D0
M2(72=?#KOF8/'T0``$B-'9HO``"0,<!(B>Y(B=_H,_+__TB%P'0V2&-4)`Q(
MBP4"CP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?
M1```2(T=5"\``)`QP$B)[DB)W^CC\?__2(7`=#9(8U0D#$B+!;*.``!(C030
M2(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1VD+@``
MD#'`2(GN2(G?Z)/Q__](A<!T-DAC5"0,2(L%8HX``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B)[DB-/;LN``#H2?'__TB)
MQDB%P'0.2(T]DRX``#'`Z./U__](B>Y(C3VG+@``,<#H(O'__TB)QDB%P'0.
M2(T]HRX``#'`Z+SU__](B>Y(C3V=+@``,<#H^_#__TB)QDB%P'0Z2(T]YBT`
M`#'`Z)7U__\QP$B--:,N``!(C3T(+@``Z(#U__](BT0D.&1(*P0E*````'51
M2(/$2%M=PTB)[DB-/5HN```QP.BH\/__2(G&2(7`=!!(C3WH+0``,<#H0O7_
M_^NK2+A005)?0TQ%04@Y1"0A=9IF@7PD*4X]=9%(C70D*^O/_Q69BP``9@\?
MA```````2(/L&&1(BP0E*````$B)1"0(BP7XC```@_C_=!M(BWPD"&1(*SPE
M*````'5"2(/$&,-F#Q]$``!(C70D!$B-/6LM```QP.@5\/__2(G",<!(A=)T
M$@^V$H#Z,`^5P3'`A-(/E<`AR(D%HXP``.NN_Q4;BP``9F8N#Q^$``````!(
M@^P(_Q4.BP``B<?_%=Z*``!(A<!T`TB+`$B#Q`C#D$%454B)_4B-/7PM``!3
M2(/L$&1(BP0E*````$B)1"0(,<!(C70D!.B4[___2(7`=`B`.`!(B<-U-TB+
M1"0(9$@K!"4H````#X6]````2(GN2(/$$$B-/2XM```QP%M=05SI"O3__V8N
M#Q^$``````!(B>Y(B<?_%=2+``!(A<!T'TB+1"0(9$@K!"4H````=7E(@\00
M6UU!7,-F#Q]$``!(B>__%3^*``!(B=])B<3_%3.*``!)C7P$`O\5P(H``$B#
M[`A)B>B^`0```%-(Q\+_____2(G'28G$3(T-[RL``$B-#=XL```QP/\5:(L`
M`%A:2(M$)`AD2"L$)2@```!U"$R)YNE&_____Q7@B0``05=!5D%528G]2(T]
MFBL``$%455-(@>R(@0``9$B+!"4H````2(F$)'B!``!(C05B+```3(UD)!Q(
MQT0D,`````!(QX0DB`````````!,B>9(QT0D4`````!(B40D($B-!?4J``!(
MB40D*$B-!<@K``!(B40D:$B-!1TL``!(B40D<$B-!<TK``!(B40D>$B-!0TL
M``!(B80D@````$B-!0(L``!(B40D2#'`Z`#N__](A<!T#(`X`$B)Q0^%KP0`
M`/\5(8D``(G'_Q7QB```2(7`#X3X`P``2(LH2(7M#X3L`P``2(GO_Q7KB```
M2(U\``'_%7B)``!$#[9%`$B)PT6$P'0W28G?3(TUH"L``)!(@\4!3(G_3(GQ
MO@$```!(Q\+_____,<!)@\<"_Q46B@``1`^V10!%A,!UU$R-="1@2(T]^"H`
M`.L79@\?1```28M^"$F#Q@A(A?\/A#\!``!,B>8QP.A%[?__2(G%2(7`=-V`
M.`!TV$B)Q^B0[___A<!TS$B)[_\5HXD``$F)QTB%P`^$!P$```\?@`````!,
MB?__%2^(``!(B=](B<7_%2.(``!$C;0%!`0``$UC]DR)]_\5IX@``%--B?A,
MC0V(*0``2(G%2(T%WRH``+X!````2,?"_____U!(C0W"*@``2(GO,<#_%4N)
M``!(B>^^P`$``/\5?8<``%]!6(/X_W43_Q5/AP``1(L(08/Y$0^%(`,``$B-
ME"20````2(GNOP$```#_%<R(``")PX7`#X2Z````28M-`$B+/5^)``!)B>@Q
MP$B-%0LK``"^`0```$4Q]O\5M8@``$B+A"1X@0``9$@K!"4H````#X5Y!0``
M2('$B($``$R)\%M=05Q!74%>05_#9@\?A```````2(ML)"!%,?;K$V8/'T0`
M`$ECQDB+;,0@2(7M=#N`?0``=#5(B>]!@\8!Z$'N__^%P'3=2(GO_Q54B```
M28G'2(7`#X6X_O__26/&2(MLQ"!(A>UUR`\?`$4Q_^F@_O__BX0DJ````"4`
M\```/0!````/A2____]$B[PDK````/\5PX8``$$YQP^%&/___XN$)*@````E
M_P$``#W``0``#X4!____3(GW_Q4BAP``2(T]+RD``$R)YDF)QC'`Z$[K__](
MB<=(A<`/A$("``#_%;R'``!)BWT`2(G&Z,#S__])B<=(A<`/A"0"``!,B?__
M%4.&``"#^`-^/DACT+D%````2(T]&2D``$F-=!?\\Z8/E\*`V@"$TG4>@_@$
M#X2)`P``@^@%2)A!@#P'+P^$>0,```\?1```BP6"AP``@_C_#X0I`P``A<`/
MA-0!``!(C36!*```2(T]`B@``#'`Z%SO__],C27P*```3(TM2B<``/\5@(4`
M`$%428GHO@$```!02,?"_____TR)]S'`3(T-)B<``$B-#9XH``#_%06'``!8
M6NM-9@\?A```````_Q42A0``@S@1=4S_%3>%``"#PP%(@^P(38GI051)B>A(
MC0UR*```3(GW4TC'PO____^^`0```%`QP/\5N(8``$B#Q""^P`$``$R)]_\5
MYH0``(/X_W2I2(GO_Q6PA```3(GV2(T]\"8``#'`Z)_N__],B??H)_K__^F=
M_?__9I`QVTB-/;`G``#K$@\?1```2&/#2(M\Q$!(A?]T.4R)YC'`@\,!Z+;I
M__](A<!TX8`X`'3<2(G'_Q4CA@``2(G%2(7`#X7+^___2&/#2(M\Q$!(A?]U
MQ[\-````2(TM7"<``/\5.(4``$&X4P```$B)P^F_^___28M-`$B+/5^&``!)
MB>@QP$B-%<LG``"^`0```$4Q]O\5M84``.G[_/__2(G'Z'CY__](BX0D>($`
M`&1(*P0E*`````^%;`(``$B!Q(B!``!(B>];74%<05U!7D%?_R6'A0``#Q^`
M`````$V+?0#IT_W__\<%G84````````Q]DR)_S'`_Q7XA```08G$A<`/A!3^
M__](C9PD<`$``+H"````2,?&[O___XG'_Q4AA0``N@8```!(B=Y$B>?_%2B$
M``"`O"1P`0```'4.@+PD<0$``$,/A&\!```QTC'V1(GG_Q7KA```,<!GZ/L;
M``!)B<7K%&8/'T0``(G"2(G>3(GO9^A"'```N@"```!(B=Y$B>?_%=&#``"%
MP'_=3(V\)"`!``!$B>=,C24Z)@``_Q65@P``3(GN3(G_3(VL)&@!``!GZ+$=
M``!(C80D0`$``$B)1"0(2(G#D$B)WTB#PP)%#[8'3(GA2,?"_____[X!````
M,<!)@\<!_Q6"A```23G===5(C04I)@``QH0D:`$```!0_W0D$$B-#>8E``!)
MB>A,B?<QP+X!````3(T-8B0``$C'PO______%4&$``!97NF9_?__9I`QP$R)
MYDB-/>,D``#HC^?__TB%P`^$C_[__P^V`(3`#X2$_O__/#`/A'S^___'!1F$
M```!````Z:/\__]-BVT(387M#X1__/__3(GO_Q5V@@``2(/X`P^&;/S__TF-
M=`7\N04```!(C3U*)0``\Z8/E\`<`(3`30]$_>E)_/__@+PD<@$``$$/A8/^
M__^`O"1S`0``0P^%=?[__X"\)'0!``!(#X5G_O__@+PD=0$``$4/A5G^__^Z
M`@```$C'QL;___]$B>?_%3R#``"Z*0```$B)WD2)Y_\50X(``$B-!0<E``!0
M4^GD_O___Q7?@0``9F8N#Q^$```````/'T``055!5%5(@^P0BSU1@P``9$B+
M!"4H````2(E$)`@QP/\5,X(``(L]-8,``$B)Q?\5)((```^VE;@```!(C6PD
M!$B-/8PC``!(B>Z(D+D````QP.A)YO__2(7`=`F`.#$/A,,!```QP.@D\?__
MBSWN@@``_Q7@@0``N0,```"Z`0```$B--6$D``!(B<?_%::!``!)B<1(A<!T
M.DB+0!"+/;R"``!,BRC_%:N!``!(C14X)```2(G'3(GN_Q4P@0``28M$)!!,
MBR!!]D0D#D`/A9P!``"+/8:"``#_%7B!``"Y`P```+H!````2(TU`"0``$B)
MQ_\5/H$``$F)Q$B%P'1`2(GN2(T]ER(``#'`Z(WE__])B<5(A<`/A"$!``!)
MBT0D$(L]-H(``$R+(/\5)8$``$R)ZDB)QTR)YO\5KH```(L]&((``/\5"H$`
M`+H!````2(TUF2,``$B)Q_\5!8$``(L]]X$``$F)Q/\5YH```$R)YDB-%8PC
M``!(B<?_%6N```"+/=6!``#_%<>```!(B>Y(C3W_(0``QH"Y`````#'`Z/?D
M__](B048D@``28G$2(7`=$"^P`$``$R)Y_\5LG\``(U0`8/Z`78)@_@1#X6V
M````2(M$)`AD2"L$)2@````/A<````!(@\0074%<05W##Q\`2(L]T9$``.CL
M]?__2(D%O9$``$F)Q$B%P'6E2(T]EB,``#'`_Q5.@```9@\?1```@'@!``^$
M.O[__^DN_O__9@\?A```````2(L%B9$``(L]$X$``$R+*$F+1"003(L@_Q7Z
M?P``3(GN3(GGZ/?G___IU/[__V:0BSWJ@```_Q7<?P``3(GF2(G'_Q4(@```
MZ4?^__^)P4B+!3J1``!,B>)(C3TX(P``2(LP,<#_%<5_``#_%1]_``!F9BX/
M'X0```````\?0`!!5%5(B?U32(/L$&1(BP0E*````$B)1"0(,<!(A?\/A+P`
M``"`/P`/A+,```#HGN;__P^V$$B)PX32=!8/'T``2(/``8#Z+P^V$$@/1-B$
MTG7NBP4X@```2(7M00^5Q(/X_P^$D````(7`#Y7`02'$183D=2-(BT0D"&1(
M*P0E*`````^%L````$B#Q!!;74%<PV8/'T0``(!]``!TU[D$````2(T]0R$`
M`$B)WO.F#Y?`'`"$P'6]2(M$)`AD2"L$)2@```!U<4B#Q!!(B>];74%<Z=CC
M__\/'X0``````$B-/:,?``#_%7-_``#I0/___V8/'T0``#'`2(UT)`1(C3TI
M(```Z-7B__](A<!T"P^V`(3`=`0\,'4/QP5K?P```````.E+____QP5<?P``
M`0```.DW_____Q71?0``D$%73(U/.$%6055!5%532('LF`(``&1(BP0E*```
M`$B)A"2(`@``,<!(B>),C90D@````$F)T&8N#Q^$``````!!BP%)BS%)@\`0
M28/!"`_(B<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(
M2,'F&('A``#_`(GV2`GP2`G(28E`^$TYT'6N2(VR``(```\?@`````!(BT)H
M2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L/3(M?
M$$B+=R!(BU\83(G(3(G*2(MO"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DR)V$B+
M="0(2#'82"'H2(VT,YEY@EI(,=A$C10"2(GJ2(GH2,'H`DC!XAY-B=!("<),
MB=A)P>@;B=%(,<A,(<A,,=A(`?!,B=9(P>8%3`G&1(TT,$R)SDR)R$C!YAY(
MP>@"38GP2`GP2(MT)!!)P>@;2#'"08G%3"'228VT,YEY@EI(,<I(`?),B?9(
MP>8%3`G&1(T$,DR)UDG!Z@)(BU0D&$C!YAY,"=9(C901F7F"6DR)P4@Q\$&)
M]$PA\$PQZ$C!Z1M(`=!,B<)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1002(GP2(M4
M)"!,"?%,B=9(,<A)C905F7F"6DC![AM!B<Y,(<!,,>!(`=!,B=)(P>(%2`GR
M1(TL$$R)PDG!Z`)(BT0D*$C!XAY,B>Y,"<))C80$F7F"6DC![AM(,=%!B=!,
M(=%,,?%(`<%,B>A(P>`%2`GP1(TD`4R)T$G!Z@)(BTPD,$C!X!Y,B>9,"=!)
MC8P.F7F"6D@QPD&)PDPAZDPQPD@!RDR)X4C!X05(P>X;2`GQ3(GN2<'M`DC!
MYAY$C30*2(M4)#A,">Y,B?%(,?!)C900F7F"6DC!Z1M!B?5,(>!,,=!(`=!,
MB?)(P>(%2`G*3(GA2<'L`DC!X1Y$C0002(GP2(M4)$!,">%,B<9(,<A)C902
MF7F"6DC![AM!B<Q,(?!,,>A(`=!,B<)(P>(%2`GR1(T4$$R)\DG![@)(BT0D
M2$C!XAY,B=9,"?))C80%F7F"6DC![AM(,=%!B=9,(<%,,>%(`<%,B=!(P>`%
M2`GP1(TL`4R)P$G!Z`)(BTPD4$C!X!Y,B>Y,"<!)C8P,F7F"6DC![AM(,<)!
MB<!,(=),,?)(`<I,B>E(P>$%2`GQ3(G62<'J`DC!YAY$C20*2(M4)%A,"=9,
MB>%(,?!)C906F7F"6DC!Z1M!B?),(>A,,<!(`=!,B>)(P>(%2`G*3(GI2<'M
M`DC!X1Y$C3002(GP2(M4)&!,">E,B?9(,<A)C900F7F"6DC![AM!B<U,(>!,
M,=!(`=!,B?)(P>(%2`GR1(T$$$R)XDB+1"1H2,'B'DG![`),B<9,">))C80"
MF7F"6DC![AM(,=%!B=1,(?%,,>E(`<%,B<!(P>`%2`GP1(T4`4R)\$G![@)(
MBTPD<$C!X!Y,B=9,"?!)C8P-F7F"6DC![AM(,<)!B<9,(<),,>)(`<I,B=%(
MP>$%2`GQ3(G&2<'H`DC!YAY$C2P*2(M4)'A,"<9,B>E(,?!)C904F7F"6DC!
MZ1M!B?!,(=!,,?!(`=!,B>I(P>(%2`G*3(G12<'J`DC!X1Y$C2002(GP2(N4
M)(````!,"=%,B>9(,<A)C906F7F"6DC![AM!B<I,(>A,,<!(`=!,B>)(P>(%
M2`GR1(TT$$R)ZDG![0)(BX0DB````$C!XAY,B?9,">I)C80`F7F"6DC![AM(
M,=%!B=5,(>%,,=%(`<%,B?!(P>`%2`GP1(T$`4R)X$G![`)(BXPDD````$C!
MX!Y,">!)C8P*F7F"6DV)PD@QPDG!ZAN)QDPA\DPQZD@!RDR)P4C!X05,"=%-
MB?))P>X"2<'B'HG)30GR2`'*2(N,))@```!,,=!!B=1,(<!)C8P-F7F"6DV)
MY4@Q\$G![1M(`<A,B>%(P>$%3`GIB<E(`<A,B<%)P>@"2,'A'D&)Q4P)P4V)
MT$6)TDP#E"2H````23'(1#'"3(N$)*````!.C80&H>O9;DR)[DD!T$R)ZDC!
M[AM(P>(%2`GRB=))`=!,B>))P>P"2,'B'D2)QDP)XDF)S(G)2`.,)+````!)
M,=1$,>!)B?1-C90"H>O9;DB)\$G![!M(P>`%3`G@B<!)`<),B>A)P>T"2,'@
M'D6)U$P)Z$F)U8G223'%13'H38GE2`.4)+@```!.C80!H>O9;DR)X4G![1M(
MP>$%3`GIB<E,`<%)B?!(P>X"2<'@'D&)S4D)\$B)QHG`2`.$),````!,,<9!
M,?)*C;02H>O9;DR)ZDV)ZDG!ZAM(P>(%3`G2B=)(`?),B>9)P>P"2,'F'D&)
MTDP)YDV)Q$6)P$P#A"3(````23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@
M!4P)X(G`2`'(3(GI2<'M`DC!X1Y!B<1,">E)B?6)]DDQS40QZDV)Y4V-A!"A
MZ]EN3(GB2,'B!4G![1M(`[0DT````$P)ZHG220'03(G22<'J`DC!XAY%B<5,
M"=))B<J)R4@#C"38````23'21#'038GJ2(VT!J'KV6Y,B>A)P>H;2,'@!4P)
MT(G`2`'&3(G@2<'L`DC!X!Y!B?),">!)B=2)TD@#E"3@````23'$13'@38G4
M3HV$`:'KV6Y,B=%)P>P;2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)
MB<6)P$TQQ40Q[DV)Y4B-M#*AZ]EN3(GB2<'M&TC!X@5,">J)TD@!\DR)UDG!
MZ@)(`X0DZ````$C!YAY!B=5,"=9-B<)%B<!,`X0D\````$DQ\D0QT4V)ZDB-
MC`BAZ]EN3(GH2<'J&TC!X`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GT
MB?9(`[0D^````$DQS$0QXDV)U$V-A!"AZ]EN3(G22<'L&TC!X@5,">*)TDD!
MT$R)ZDG![0)(P>(>18G$3`GJ28G-B<E),=5$,>A-B>5(C;0&H>O9;DR)X$G!
M[1M(P>`%3`GHB<!(`<9,B=!(P>`>2<'J`D&)]4@#C"0``0``3`G028G2B=)(
M`Y0D"`$``$DQPD4QT$V)ZDZ-A`&AZ]EN3(GI2<'J&TC!X05,"=&)R4P!P4V)
MX$G![`))P>`>08G*30G@28G$B<!(`X0D$`$``$TQQ$0QYDV)U$B-M#*AZ]EN
M3(G22<'L&TC!X@5,">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`23'U
M1#'I38GE2(V,"*'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'(3(G12<'J`DC!X1Y!
MB<5,"=%)B?),`X0D&`$``(GV23'*2`.T)"`!``!$,=)-C;00H>O9;DR)ZDV)
MZ$G!Z!M(P>(%3`G"28G(B<E(`XPD*`$``(G220'63(GB2<'L`DC!XAY%B?),
M">)),=!$,<!,C:0&H>O9;DR)T$R)UDC![AM(P>`%2`GP2(G6B=)(`Y0D,`$`
M`(G`20'$3(GH2<'M`DC!X!Y%B>!,">A(,<9!,?9,B<9.C:PQH>O9;DR)P4C!
M[AM(P>$%2`GQB<E)`<U,B=%)P>H"2,'A'D2)[DP)T4F)PHG`23'*13'42`.$
M)#@!``!.C90BH>O9;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-
M"<1)B<B)R4TQX$2)XD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD
M0`$``$6--`!)B?!(P>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/
M20'%3`'I38GU3`'A38GT2<'M&TG!Y`5-">Q!`<Q,B=%)P>H"2,'A'DP)T4D)
MR$F)S4&)RDTA\$DA]4T)Z$R+K"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!
MX@5,">I%C2P03(GR2<'N`DC!XAY,"?))B<Y!B=!)"=9-(>9,(<%,"?%,B[0D
M4`$``$D!QDP!]DV)[D@!\4R)[DG![AM(P>8%3`GV1(TT,4R)YDG![`)(P>8>
M3`GF2`GR28GTB?%-(<1,(>I,">),BZ0D6`$``$D!Q$T!XDV)]$P!TDV)\DG!
MX@5)P>P;30GB1HTD$DV)ZDG![0))P>(>30GJ28GU1(G230G532'U2"'63`GN
M3(NL)&`!``!)`<5-`>A-B>5,`<9-B>!)P>T;2<'@!4T)Z$:-+`9-B?!)P>X"
M2<'@'DT)\$T)PDV)QD2)QDDAUDTAXDT)\DR+M"1H`0``20'&3`'Q38GN20'*
M3(GI2<'N&TC!X05,"?%%C30*3(GA2<'L`DC!X1Y,">%-B<1)"<Q!B<I-(>Q-
M(=!-">!,BZ0D<`$``$D!Q$P!XDV)]$D!T$R)\DG![!M(P>(%3`GB18TD$$R)
MZDG![0)(P>(>3`GJ2`G128G508G032'53"'Q3`GI3(NL)'@!``!)`<5,`>Y-
MB>5(`?%,B>9)P>T;2,'F!4P)[D2-+#%,B?9)P>X"2,'F'DP)]DF)UHGQ20GV
M32'F2"'*3`GR3(NT)(`!``!)`<9-`?)-B>Y,`=)-B>I)P>X;2<'B!4T)\D:-
M-!)-B>))P>P"2<'B'DT)XDP)UDV)U$2)TDDAS$PA[DP)YDR+I"2(`0``20'$
M30'@38GT3`'&38GP2<'L&TG!X`5-">!&C20&38GH2<'M`DG!X!Y-">A-B=5$
MB<9-"<5-(?5)(?)-">I,BZPDD`$``$D!Q4P!Z4V)Y4D!RDR)X4G![1M(P>$%
M3`GI18TL"DR)\4G![@)(P>$>3`GQ20G(28G.08G*22'V32'@30GP3(NT))@!
M``!)`<9,`?)-B>Y)`=!,B>I)P>X;2,'B!4P)\D6--!!,B>))P>P"2,'B'DP)
MXDF)S$&)T$D)U$TA[$PAP4P)X4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L
M&TC!Y@5,">9$C20Q3(GN2<'M`DC!YAY,">Y("?))B?6)\4TAQ4PA\DP)ZDR+
MK"2H`0``20'%30'J38GE3`'238GB2<'M&TG!X@5-">I&C2P238GR2<'N`DG!
MXAY-"?))B?9$B=)-"=9-(>9((=9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)
MZ$G![AM)P>`%30GP1HTT!DV)X$G![`))P>`>30G@30G"38G$1(G&22'432'J
M30GB3(ND)+@!``!)`<1,`>%-B?1)`<I,B?%)P>P;2,'A!4P)X46-)`I,B>E(
MP>$>2<'M`DP)Z4V)Q4&)RDD)S4TA]4TAT$T)Z$R+K"3``0``20'%3`'J38GE
M20'03(GB2<'M&TC!X@5,">I%C2P03(GR2<'N`DC!XAY,"?)("=%)B=!!B==-
M(=!,(>%,"<%,BX0DR`$``$D!P$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$
M,4R)YDG![`)(B=%(P>8>3`GF08GT2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%(
M`X0DV`$``$D!RDR)P4D!QTP!TDV)PDC!X05)P>H;3`G1B<E(`<I,B>E)P>T"
M2,'A'D&)TDP)Z4R)T$@)SDF)S4C!X`5!B<Y-(>5,(<9,">Y-B=5)P>T;3`'^
M3`GHB<!(`<9,B<!)P>@"2,'@'D&)]4D)P+C6P6+*3#'!,<I(BXPDX`$``$@!
MP4P!X4V)[$@!T4R)ZDG![!M(P>(%3`GBB=)(`=%,B=))P>H"2,'B'D&)S$D)
MTDR)PD6)P$PQTC'62(N4).@!``!(`<))`=9,B>),`?9-B>9(P>(%2<'N&TP)
M\HG23(TT%DR)ZDG![0),B=9(P>(>18GW18G220G52(N4)/`!``!,,>Y(`<(Q
M\4R)_DP!PDC![AM(`=%,B?I(P>(%2`GR2(NT)/@!``")TD@!T4R)XD@!QDG!
M[`)(P>(>3`'638GJ08G(3`GB38G$18GM23'213'63HT4-DR)QDC!Y@5)P>P;
M3`GFB?9)`?),B?Y)P>\"2,'F'D6)U$D)]TB+M"0``@``2`'&3`'N28G5B=)-
M,?U$,>E,C2P.3(GA3(GF2,'N&TC!X05("?%,B<9)P>@"B<E(P>8>20'-2(N,
M)`@"``!,"<9-B?A),?!%B>Y%B?](`<%%,<)(`<I,B?%.C0023(GR2,'I&TC!
MX@5("<I(B?&)]HG220'03(GB2<'L`DC!XAY%B<))"=1(BY0D$`(``$PQX4@!
MPD$QS4R)T4P!^DD!U4R)TDC!Z1M(P>(%2`G*3(GQ2<'N`HG22,'A'DD!U4B+
ME"08`@``3`GQ18GO2`'"2`'R3(GF18GD2#'.03'P3(G^20'03(GZ2,'N&TC!
MX@5("?*)TDD!T$R)TDG!Z@)(P>(>18G&20G22(N4)"`"``!,B?9(P>X;2`'"
M3`'B28G,B<E-,=1%,>5.C20J3(GR2,'B!4@)\DB+M"0H`@``B=))`=1,B?I(
M`<9)P>\"2,'B'D6)Y4P)^D@!\4R)UD6)TD@QUD$Q\$R)[DD!R$R)Z4C![AM(
MP>$%2`GQB<E)`<A,B?%)P>X"2,'A'D6)QTD)SDB+C"0P`@``3(G^2,'N&T@!
MP4P!T4F)THG233'R13'43HT4(4R)^4C!X05("?%,B>Y)P>T"B<E(P>8>20'*
M2(N,)#@"``!,">Y%B=1(`<%(`<I,B?%%B?9(,?%!,<A,B>%)`=!,B>)(P>D;
M2,'B!4@)RDB)\8GVB=))`=!,B?I(P>(>2<'O`D6)Q4D)UTB+E"1``@``3#'Y
M2`'"03'*3(GI3`'R2,'I&TD!TDR)ZDC!X@5("<I,B>%)P>P"B=)(P>$>20'2
M2(N4)$@"``!,">%%B?Q%B=9(`<)(`?),B?Y(,<Y!,?!*C30"3(GR38GP2<'H
M&TC!X@5,"<*)TD@!UDR)ZDG![0)(P>(>08GP20G52(N4)%`"``!(`<),`>))
MB<R)R4TQ[$4QXDZ-)!),B<)-B<))P>H;2,'B!4P)THG220'43(GR2<'N`DC!
MXAY%B>),"?),B[0D6`(``$D!QDP!\4V)[D6)[4DQUD0Q]DV)UD@!SDR)T4G!
M[AM(P>$%3`GQB<E(`<Y,B<%)P>@"2,'A'D&)]DD)R$B+C"1@`@``2`'!20'-
M2(G1B=),,<%!,<Q+C4PE`$V)]$V)]4G![1M)P>0%30GL38G52<'J`DG!Y1Y%
MB>1-">I,BZPD:`(``$P!X4&)S$D!Q4P!ZDV)Q46)P$TQU40Q[DR-+#),B>),
MB>9(P>(%2,'N&T@)\HG220'53(GR2<'N`DC!XAY$B>Y)"=9(BY0D<`(``$@!
MPD@#A"1X`@``3`'"38G033'P1#'!28GP2`'*2(GQ2<'H&TC!X05,"<%%B=`!
MT4R)XDG![`)(P>(>20G42HT4"$B)R$D!T$R)\DC!X`5$`>-,,>)(B5\803'5
M2XT4*$F)R`'I2<'H&TB)3PA,"<`!T$B)!TB)\$C![@)(P>`>2`G&00'S1`-W
M($R)7Q!,B7<@2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?
MP_\5LV<```\?`$B#[`B_@````/\5,6@``+J)J\WON?[<NIB^\.'2PTC'``$C
M16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````
M2(/$",-F9BX/'X0``````$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L
M"$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0``
M`$&#_C\/CC,!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG
M2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HX>C__TPYZW7,
M0<'G!D4I_DECQDB#^`AR7$F+50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@I
MU4DI[4@!Q4B#Y?A(@_T(<AA(@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D
M>$B#Q`A;74%<05U!7D%?PV:0J`1U?$B%P'3A00^V50!!B%0D.*@"=--!#[=4
M!?YFB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GN10].[DUC_4R)^O\5
M;&8``$&+1"1X1`'H08E$)'B#^$!UD4R)YT4I[DP!^^@$Z/__Z<K^__\/'X``
M````28G=Z1O___]!BU4`08E4)#A!BU0%_(E4!?SI4____V8/'X0``````$%6
M3(UV.$%505152(GU4TB+1BA(B?M$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(
MF,9$!CB`2&/!3`'P@_DX#XXL`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S
M2(GOZ&SG__]F#^_`#Q%%.$G'1C``````00\11A!!#Q%&($2);7!(B>]$B65T
MZ$+G__](BT4`2(GO2,'H&(@#2(M%`$C!Z!"(0P%(BT4`2,'H"(A#`DB+10"(
M0P-(BT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%"$C!Z`B(0P9(BT4(B$,'2(M%
M$$C!Z!B(0PA(BT402,'H$(A#"4B+11!(P>@(B$,*2(M%$(A#"TB+11A(P>@8
MB$,,2(M%&$C!Z!"(0PU(BT482,'H"(A##DB+11B(0P](BT4@2,'H&(A#$$B+
M12!(P>@0B$,12(M%($C!Z`B(0Q)(BT4@B$,36UU!7$%=05[_);IC``!F+@\?
MA```````NC@````Q_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A
M^$@IR`'"@^+X@_H(#X+5_O__@^+X,<")QH/`"$B)/#$YT'+SZ;[^___VP@1U
M(X72#X2Q_O__Q@``]L("#X2E_O__,<EFB4P0_NF9_O__#Q\`QP``````QT00
M_`````#I@_[__P\?1```\P\>^D%73(T]PV```$%628G6055)B?5!5$&)_%5(
MC2VT8```4TPI_4B#[`CHW\3__TC!_0-T'S';#Q^``````$R)\DR)[D2)YT'_
M%-](@\,!2#G==>I(@\0(6UU!7$%=05Y!7\-F9BX/'X0``````/,/'OK#9BX/
M'X0``````)#S#Q[Z2(L-C60``.FPQ/__\P\>^DB#[`A(@\0(PP``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-3(`+64`+2T``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@
M,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R
M96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E
M("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D[
M"B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I
M92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P
M97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`!&P,[_````!X```"0@?__,`$``+"!__^\!0``T(/__Q@!``#0A/__6`$`
M`*"%__^D`0``,(?__^@!``#`A___#`(``)"(__\T`@``@(G__W@"``#0B___
MQ`(``$",___<`@``@(S___0"``!0C?__*`,``&"-__\\`P``<(___YP#``"@
MC___L`,``,"/___$`P``<)3___`#``#PE/__#`0``!"5__\D!```();__W0$
M```PGO__1`4``/"@__]X!0``,*+__^@%``!0N/__.`8``+"X__]0!@``8+K_
M_YP&``!@O/__X`8``-"\__\H!P``X+S__T`'````````%``````````!>E(`
M`7@0`1L,!PB0`0``%````!P```"P@O__+P````!$!Q``````)````#0```!8
M@/__(``````.$$8.&$H/"W<(@``_&CLJ,R0B`````$@```!<````<(/__\T`
M````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FT*#CA$#C!!
M#BA"#B!"#AA"#A!"#@A("P!`````J````/2#__^-`0```$(.$(X"0@X8C0-"
M#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+`"````#L
M````0(7__XP`````00X0A@)2#K`!`G$*#A!!#@A!"R0````0`0``K(7__\8`
M````00X0A@("6PH."$P+`D$*#@A!"U8."`!`````.`$``%2&___G`````$(.
M$(\"1PX8C@-"#B"-!$(.*(P%1`XPA@91#L`@`H8*#C!!#BA"#B!"#AA"#A!"
M#@A'"T@```!\`0```(?__T("````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D0..(,'1PY0`QT!"@XX00XP00XH0@X@0@X80@X00@X(10L4````R`$```2)
M__]N`````$0.$`)D#@@4````X`$``%R)__\R`````$0.$%<."``P````^`$`
M`(2)___%`````$(.$(P"00X8A@-!#B"#!$<.P$`"K`H.($0.&$$.$$(."$$+
M$````"P"```@BO__!0````````!<````0`(``!R*__\%`@```$(.$(\"0@X8
MC@-"#B"-!$4.*(P%00XPA@9+#CB#!T<.\"$"90H..$$.,$$.*$(.($(.&$(.
M$$(."$,+`JX.^"%(#H`B9`[X(4$.\"$````0````H`(``,R+__\E````````
M`!````"T`@``Z(O__QT`````````*````,@"``#TB___IP0```!!#A"&`D$.
M&(,#2PY@`T<$"@X800X000X(00L8````]`(``'B0__]U`````$0.(&T*#@A'
M"P``%````!`#``#<D/__'P````!$#A!:#@@`3````"@#``#DD/__$`$```!"
M#A",`D$.&(8#2PX@@P1$#C`"0@H.($H.&$$.$$(."$\+90H.($$.&$$.$$(.
M"$<+9`XX20Y`9`XX00XP``#,````>`,``*21__\!"````$(.$(\"0@X8C@-"
M#B"-!$P.*(P%00XPA@9!#CB#!T<.P(,"`Z\!#LB#`F$.T(,"80[(@P)"#L"#
M`@)["@XX1`XP00XH0@X@0@X80@X00@X(2@L#>@$.R(,"20[0@P)A#LB#`D$.
MP(,"8P[(@P)%#M"#`DX.V(,"30[@@P),#L"#`@,"`0H..$0.,$$.*$(.($(.
M&$(.$$(."$T+`RL!#LB#`D0.T(,":0[(@P)!#L"#`@+L"@[(@P)!#M"#`D4+
M,````$@$``#DF/__L0(```!"#A"-`D(.&(P#00X@A@1$#C`#Y@$*#B!!#AA"
M#A!"#@A$"T````!\!```<)O__S\!````0@X0C`)!#AB&`T0.((,$1`XP`H(*
M#B!!#AA!#A!"#@A'"W0*#B!$#AA!#A!"#@A-"P``*````,`$``#L>___'@(`
M``!"#A",`D$.&(8#1`Y0`[`!"@X81`X00@X(00M,````[`0``$"<__\=%@``
M`$(.$(\"1@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#]Q4*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A!"P```!0````\!0``$++__U4`````1`X0`E`."$@`
M``!4!0``6++__Z<!````0@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D4..(,'
M1PY``N4*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"P!`````H`4``+RS___[`0``
M`$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#2@$*#BA!#B!"#AA"#A!"#@A0
M"P```````$0```#D!0``>+7__V4`````1@X0CP))#AB.`T4.((T$10XHC`5$
M#C"&!D@..(,'1PY`;@XX00XP00XH0@X@0@X80@X00@X(`!0````L!@``H+7_
M_P4``````````````!````!$!@``F+7__Q``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````4",`````````(P````````$`````````\@(````````!`````````/T"
M`````````0`````````-`P````````\`````````F`0````````,````````
M```@````````#0````````"`6P```````!D`````````P+L````````;````
M``````@`````````&@````````#(NP```````!P`````````"`````````#U
M_O]O``````@#````````!0````````#(#0````````8`````````L`0`````
M```*`````````+L$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````8`````````!0`````````
M!P`````````7`````````%@:````````!P````````#($P````````@`````
M````D`8````````)`````````!@`````````&````````````````````/O_
M_V\``````0``"`````#^__]O`````$@3````````____;P`````"````````
M`/#__V\`````A!(```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#0NP``````````````````````````
M```V(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$=.52D@,3`N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````*@"````````J`(````````<````````````
M`````````0```````````````````!,````'`````@````````#$`@``````
M`,0"````````)`````````````````````0````````````````````F````
M!P````(`````````Z`(```````#H`@```````"`````````````````````$
M````````````````````-````/;__V\"``````````@#````````"`,`````
M``"H`0````````4`````````"````````````````````#X````+`````@``
M``````"P!````````+`$````````&`D````````&`````0````@`````````
M&`````````!&`````P````(`````````R`T```````#(#0```````+L$````
M```````````````!````````````````````3@```/___V\"`````````(02
M````````A!(```````#"``````````4``````````@`````````"````````
M`%L```#^__]O`@````````!($P```````$@3````````@``````````&````
M`@````@```````````````````!J````!`````(`````````R!,```````#(
M$P```````)`&````````!0`````````(`````````!@`````````=`````0`
M``!"`````````%@:````````6!H````````8``````````4````5````"```
M```````8`````````'X````!````!@``````````(``````````@````````
M&P````````````````````0```````````````````!Y`````0````8`````
M````("`````````@(````````"`````````````````````0`````````!``
M````````A`````$````&`````````$`@````````0"````````!`.P``````
M````````````$````````````````````(H````!````!@````````"`6P``
M`````(!;````````#0````````````````````0```````````````````"0
M`````0````(``````````&``````````8````````)`^````````````````
M```0````````````````````F`````$````"`````````)">````````D)X`
M``````#\````````````````````!````````````````````*8````!````
M`@````````"0GP```````)"?````````6`8```````````````````@`````
M``````````````"P````#@````,`````````P+L```````#`JP````````@`
M```````````````````(``````````@`````````O`````\````#````````
M`,B[````````R*L````````(````````````````````"``````````(````
M`````,@````&`````P````````#0NP```````-"K````````(`(````````&
M``````````@`````````$`````````#1`````0````,`````````\+T`````
M``#PK0```````!`"```````````````````(``````````@`````````U@``
M``$````#``````````#``````````+`````````@````````````````````
M"````````````````````-P````(`````P`````````@P````````""P````
M````@!```````````````````"````````````````````#A`````0```#``
M```````````````````@L````````!(````````````````````!````````
M``$``````````0````,`````````````````````````,K````````#J````
<`````````````````0``````````````````````
